from sqlalchemy import Column, Integer, String, TIMESTAMP, ForeignKey, UniqueConstraint, func
from sqlalchemy.orm import relationship

from .base_model import Base

class BookCategory(Base):
    __tablename__ = 'book_category'
    __table_args__ = (UniqueConstraint('name'),)

    id = Column(Integer, primary_key=True, autoincrement=True)
    name = Column(String(100), nullable=False)
    last_updated = Column(TIMESTAMP, nullable=False, server_default=func.now())

    books = relationship(
        'Book',
        secondary='book_category_link',
        back_populates='categories',
    )
    book_category_statistics = relationship('BookCategoryStatistics', backref='book_category_statistics')



__all__ = ["BookCategory"]
