from sqlalchemy import Column, String, TIMESTAMP, Integer, Text, Enum, DECIMAL, Boolean

from .base_model import Base
from .book_model import BookStatusEnum

class BooksOverview(Base):
    __tablename__  = 'books_overview'
    __table_args__ = {'extend_existing': True}


    id             = Column(Integer, primary_key=True)
    title          = Column(String, nullable=False)
    author_name    = Column(String, nullable=False)
    author_id      = Column(Integer, nullable=False)
    categories     = Column(Text, nullable=True)
    year_published = Column(Integer, nullable=True)
    isbn           = Column(String, nullable=True)
    price          = Column(DECIMAL(5, 2), nullable=False, default=0)
    is_damaged     = Column(Boolean, nullable=False, default=False)
    status         = Column(Enum(BookStatusEnum), nullable=False)
    created_at     = Column(TIMESTAMP, nullable=False)

    # This prevents accidental updates/deletes as it's a view
    def __repr__(self):
        return (f"<BooksOverview(id={self.id}, title={self.title}, author_name={self.author_name}, "
                f"categories={self.categories}, year_published={self.year_published}, isbn={self.isbn}, "
                f"status={self.status}, created_at={self.created_at}, borrower_name={self.borrower_name}, "
                f"librarian_name={self.librarian_name})>")


__all__ = ["BooksOverview"]
