from PySide6.QtGui import QAction
from PySide6.QtWidgets import (
    QWidget, QVBoxLayout, QHBoxLayout, QLabel, QLineEdit, QScrollArea,
    QFrame, QPushButton, QMessageBox, QVBoxLayout
)
from PySide6.QtCore import Qt

from .book_card import BookCard
from models import BooksOverview

from database.manager import DatabaseManager
from database.book_overview import fetch_all_book_overviews

from ui.editor import MemberEditor


class BookOverviewList(QWidget):
    def __init__(self, parent = None):
        self.parent = parent
        super().__init__(parent=parent)

        # Central widget and layout
        main_layout = QVBoxLayout(self)

        # Title label
        title_label = QLabel("Dashboard", self)
        title_label.setAlignment(Qt.AlignCenter)
        title_label.setStyleSheet(
            "font-size: 20px; font-weight: bold; color: #0078D4;")
        main_layout.addWidget(title_label)

        # Search bar
        self.search_input = QLineEdit()
        self.search_input.setPlaceholderText("Search in books...")
        self.search_input.textChanged.connect(self.filter_books)
        main_layout.addWidget(self.search_input)

        # Scrollable area for cards
        self.scroll_area = QScrollArea()
        self.scroll_area.setWidgetResizable(True)

        # Container widget for the scroll area
        self.scroll_widget = QWidget()
        self.scroll_layout = QVBoxLayout(self.scroll_widget)
        self.scroll_layout.setSpacing(5) # Set gap between individual cards
        self.scroll_layout.setContentsMargins(0, 0, 0, 0) # Remove spacing from all sides which is present by default

        # Align the cards to the top
        self.scroll_layout.setAlignment(Qt.AlignTop)
        self.books = []
        self.book_cards = []
        self.redraw_cards()

        self.scroll_widget.setLayout(self.scroll_layout)
        self.scroll_area.setWidget(self.scroll_widget)
        main_layout.addWidget(self.scroll_area)

        # Buttons for actions
        button_layout = QHBoxLayout()
        register_member_button = QPushButton("Add New Member")
        register_member_button.clicked.connect(self.register_member)
        button_layout.addWidget(register_member_button)

        main_layout.addLayout(button_layout)

    def filter_books(self, text):
        """Filter the cards based on the search input."""
        for card, book in zip(self.book_cards, self.books):

            title_contains_text = text.lower() in book.title.lower()
            author_name_contains_text = text.lower() in book.author_name.lower()
            isbn_contains_text = text.lower() in book.isbn

            card.setVisible(title_contains_text or author_name_contains_text or isbn_contains_text)

    def register_member(self):
        MemberEditor().exec()
        self.parent.refresh_member_cards()

    def add_borrow_record(self):
        QMessageBox.information(self, "Add Borrow Record",
                                "Open dialog to add a borrow record.")

    def clear_layout(self, layout):
        while layout.count():
            item = layout.takeAt(0)
            widget = item.widget()
            if widget is not None:
                widget.deleteLater()
            else:
                sub_layout = item.layout()
                if sub_layout is not None:
                    self.clear_layout(sub_layout)
            del item

    def redraw_cards(self):
        self.clear_layout(self.scroll_layout)
        self.book_cards = []

        self.books = fetch_all_book_overviews()
        
        for book in self.books:
            card = BookCard(book)

            self.scroll_layout.addWidget(card)
            self.book_cards.append(card)


__all__ = ["BookOverviewList"]
