from PySide6.QtGui import QGuiApplication, QAction, Qt
from PySide6.QtQml import QQmlApplicationEngine
from PySide6.QtWidgets import QHBoxLayout, QVBoxLayout, QLabel, QWidget, QMenu, QSizePolicy, QLayout, QMessageBox
from PySide6.QtCore import qDebug

from ui.editor import BookEditor

from models import BookCategoryStatisticsOverview

from database.manager import DatabaseManager


class BookCategoryStatisticsOverviewCard(QWidget):
    def __init__(self, book_category_statistics_overview: BookCategoryStatisticsOverview):
        super().__init__()

        self.book_category_statistics_overview = book_category_statistics_overview

        self.setAttribute(Qt.WidgetAttribute.WA_Hover, True)  # Enable hover events
        # Enable styling for background
        self.setAttribute(Qt.WidgetAttribute.WA_StyledBackground, True)

        # Set initial stylesheet with hover behavior
        self.setStyleSheet("""
            BookCategoryStatisticsOverviewCard:hover {
                background-color: palette(highlight);
            }
        """)

        # Layout setup
        layout = QHBoxLayout(self)
        layout.setSizeConstraint(QLayout.SizeConstraint.SetMinimumSize)
        self.setSizePolicy(QSizePolicy.Policy.Preferred,
                           QSizePolicy.Policy.Fixed)

        layout.setContentsMargins(10, 10, 10, 10)
        layout.setSpacing(10)

        # Left-side content
        left_side = QVBoxLayout()
        layout.addLayout(left_side)
        category_name_label = QLabel(book_category_statistics_overview.name)
        category_name_label.setStyleSheet("font-size: 20px; font-weight: bold;")
        left_side.addWidget(category_name_label)

        # Right-side content
        right_side = QVBoxLayout()
        layout.addLayout(right_side)

        status_label = QLabel(str(book_category_statistics_overview.book_count))
        status_label.setStyleSheet("font-size: 20px; font-weight: bold;")
        status_label.setAlignment(Qt.AlignmentFlag.AlignRight)

        right_side.addWidget(status_label)

        self.setLayout(layout)

__all__ = ["BookCategoryStatisticsOverviewCard"]
