from PySide6.QtGui import QAction
from PySide6.QtWidgets import (
    QWidget, QVBoxLayout, QHBoxLayout, QLabel, QLineEdit, QScrollArea,
    QFrame, QPushButton, QMessageBox, QVBoxLayout
)
from PySide6.QtCore import Qt

from .category_overview_card import BookCategoryStatisticsOverviewCard
from models import BookCategoryStatisticsOverview

from database.manager import DatabaseManager
from database import fetch_all_book_category_statistics_overviews

class BookCategoryStatisticsOverview(QWidget):
    def __init__(self, parent = None):
        self.parent = parent
        super().__init__(parent=parent)

        # Central widget and layout
        main_layout = QVBoxLayout(self)

        # Title label
        title_label = QLabel("Category statistics", self)
        title_label.setAlignment(Qt.AlignCenter)
        title_label.setStyleSheet(
            "font-size: 20px; font-weight: bold; color: #0078D4;")
        main_layout.addWidget(title_label)

        # Search bar
        self.search_input = QLineEdit()
        self.search_input.setPlaceholderText("Search in categories...")
        self.search_input.textChanged.connect(self.filter_categories)
        main_layout.addWidget(self.search_input)

        # Scrollable area for cards
        self.scroll_area = QScrollArea()
        self.scroll_area.setWidgetResizable(True)

        # Container widget for the scroll area
        self.scroll_widget = QWidget()
        self.scroll_layout = QVBoxLayout(self.scroll_widget)
        self.scroll_layout.setSpacing(5) # Set gap between individual cards
        self.scroll_layout.setContentsMargins(0, 0, 0, 0) # Remove spacing from all sides which is present by default

        # Align the cards to the top
        self.scroll_layout.setAlignment(Qt.AlignTop)
        self.category_overviews = []
        self.category_overview_cards = []
        self.redraw_cards()

        self.scroll_widget.setLayout(self.scroll_layout)
        self.scroll_area.setWidget(self.scroll_widget)
        main_layout.addWidget(self.scroll_area)

    def filter_categories(self, text):
        """Filter the cards based on the search input."""
        for card, category in zip(self.category_overview_cards, self.category_overviews):

            name_contains_text = text.lower() in category.name.lower()

            card.setVisible(name_contains_text)


    def clear_layout(self, layout):
        while layout.count():
            item = layout.takeAt(0)
            widget = item.widget()
            if widget is not None:
                widget.deleteLater()
            else:
                sub_layout = item.layout()
                if sub_layout is not None:
                    self.clear_layout(sub_layout)
            del item

    def redraw_cards(self):
        self.clear_layout(self.scroll_layout)
        self.category_overview_cards = []

        self.category_overviews = fetch_all_book_category_statistics_overviews()
        
        for category in self.category_overviews:
            card = BookCategoryStatisticsOverviewCard(category)

            self.scroll_layout.addWidget(card)
            self.category_overview_cards.append(card)


__all__ = ["BookCategoryStatisticsOverview"]
