import logging
import sys

from PySide6 import QtWidgets
from PySide6.QtWidgets import QDialog, QMessageBox

from utils.config import UserConfig, TransactionLevel

class SettingsDialog(QDialog):
    def __init__(self, parent=None):
        super().__init__(parent)
        self.logger = logging.getLogger(__name__)
        self.user_config = UserConfig()

        self.setWindowTitle("Settings")
        self.setMinimumSize(400, 100)

        # Create layout
        layout = QtWidgets.QVBoxLayout(self)

        data_mode_layout = QtWidgets.QHBoxLayout()

        # Transaction isolation level
        self.data_mode_label = QtWidgets.QLabel(UserConfig.get_friendly_name("transaction_level") + ":")
        data_mode_layout.addWidget(self.data_mode_label)

        self.data_mode_selected = QtWidgets.QLabel(self.user_config.transaction_level.name.capitalize())
        data_mode_layout.addWidget(self.data_mode_selected)


        # Slowdown simulation
        self.slowdown_layout = QtWidgets.QHBoxLayout()
        
        self.slowdown_label = QtWidgets.QLabel(UserConfig.get_friendly_name("simulate_slowdown") + ":")
        self.slowdown_layout.addWidget(self.slowdown_label)

        self.slowdown_checkbox = QtWidgets.QCheckBox()
        self.slowdown_checkbox.setChecked(self.user_config.simulate_slowdown)

        self.slowdown_layout.addWidget(self.slowdown_checkbox)

        layout.addLayout(data_mode_layout)
        layout.addLayout(self.slowdown_layout)

        # Slowdown simulation
        simulate_slowdown = self.user_config.simulate_slowdown
        self.slowdown_checkbox.setChecked(simulate_slowdown)

        # Buttons
        button_layout = QtWidgets.QHBoxLayout()
        
        self.save_button = QtWidgets.QPushButton("Save")
        self.save_button.clicked.connect(self.save_settings)
        button_layout.addWidget(self.save_button)

        self.cancel_button = QtWidgets.QPushButton("Cancel")
        self.cancel_button.clicked.connect(self.reject)
        button_layout.addWidget(self.cancel_button)

        layout.addLayout(button_layout)

    def save_settings(self):
        simulate_slowdown = self.slowdown_checkbox.isChecked()
        self.logger.debug("Saving user configuration")
        config = UserConfig()
        config.simulate_slowdown = simulate_slowdown
        self.accept()
