import sys
import os
import logging

def setup_logger():
    logger = logging.getLogger()
    
    verbosity = os.getenv("VERBOSITY", "DEBUG").upper()
    level_map = {
        "DEBUG": logging.DEBUG,
        "INFO": logging.INFO,
        "WARNING": logging.WARNING,
        "ERROR": logging.ERROR,
        "CRITICAL": logging.CRITICAL,
    }
    log_level = level_map.get(verbosity, logging.DEBUG)  # Default to DEBUG if invalid

    logger.setLevel(log_level)

    handler = logging.StreamHandler(sys.stdout)
    handler.setLevel(log_level)

    formatter = logging.Formatter("[%(levelname)s] - %(name)s:%(lineno)d - %(message)s")
    handler.setFormatter(formatter)

    logger.addHandler(handler)
